/*
 * JBoss, Home of Professional Open Source
 * Copyright 2012, Red Hat, Inc. and/or its affiliates, and individual
 * contributors by the @authors tag. See the copyright.txt in the 
 * distribution for a full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.as.quickstarts.helloworld;

import java.io.IOException;
import java.io.PrintWriter;

import javax.inject.Inject;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.acme.insurance.Driver;
import org.acme.insurance.Policy;
import org.kie.api.KieServices;
import org.kie.api.builder.ReleaseId;
import org.kie.api.runtime.KieContainer;
import org.kie.api.runtime.KieSession;

import com.sample.Message;

/**
 * <p>
 * A simple servlet taking advantage of features added in 3.0.
 * </p>
 * 
 * <p>
 * The servlet is registered and mapped to /HelloServlet using the {@linkplain WebServlet
 * @HttpServlet}. The {@link HelloService} is injected by CDI.
 * </p>
 * 
 * @author Pete Muir
 * 
 */
@SuppressWarnings("serial")
@WebServlet("/HelloWorld")
public class HelloWorldServlet extends HttpServlet {

   static String PAGE_HEADER = "<html><head><title>helloworld</title><body>";

   static String PAGE_FOOTER = "</body></html>";

   @Inject
   HelloService helloService;

   @Override
   protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
      resp.setContentType("text/html");
      PrintWriter writer = resp.getWriter();
      try
      {
    	/*KieServices ks = KieServices.Factory.get();
      	KieContainer kContainer = ks.newKieContainer(ks.newReleaseId("br.com.bankline", "itau", "1.0"));
      	KieSession kSession = kContainer.newKieSession();
      	Message message = new Message();
      	message.setMessage("Hello World");
      	message.setStatus(Message.HELLO);
      	kSession.insert(message);
      	kSession.fireAllRules();*/
    	KieServices ks = KieServices.Factory.get();
        ReleaseId releaseId = ks.newReleaseId("org.acme.insurance", "policyquote", "1.0");
        KieContainer kContainer = ks.newKieContainer(releaseId);
        KieSession kSession = kContainer.newKieSession();
        Driver d = new Driver();
        d.setAge(30);
        d.setNumberOfAccidents(0);
        d.setNumberOfTickets(0);
        d.setCreditScore(715);
        Policy p1 = new Policy();
        p1.setVehicleYear(2000);
        p1.setPolicyType("AUTO");
        p1.setDriver(d);
        Policy p2 = new Policy();
        p2.setVehicleYear(2001);
        p2.setPolicyType("AUTO");
        p2.setDriver(d);
        Policy pM = new Policy();
        pM.setPolicyType("MASTER");
        pM.setDriver(d);
    
        kSession.insert(d);
        kSession.insert(p1);
        kSession.insert(p2);
        kSession.insert(pM);
      	kSession.fireAllRules();	  
      	System.out.println("P1 price = " + p1.getPrice());
      	System.out.println("P1 discount = " + p1.getPriceDiscount());
      	System.out.println("P2 price = " + p2.getPrice());
      	System.out.println("P2 discount = " + p2.getPriceDiscount());
      	System.out.println("PM price = " + pM.getPrice());
      }
      catch (Exception e)
      {
    	  e.printStackTrace();
      }
      writer.println(PAGE_HEADER);
      writer.println("<h1>" + helloService.createHelloMessage("World") + "</h1>");
      writer.println(PAGE_FOOTER);
      writer.close();
   }

}
